==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/devices/kotlin/inputs/EnrichmentPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devices.kotlin.inputs

import com.pulumi.azurenative.devices.inputs.EnrichmentPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of an enrichment that your IoT hub applies to messages delivered to endpoints.
 * @property endpointNames The list of endpoints for which the enrichment is applied to the message.
 * @property key The key or name for the enrichment property.
 * @property value The value for the enrichment property.
 */
public data class EnrichmentPropertiesArgs(
    public val endpointNames: Output<List<String>>,
    public val key: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.devices.inputs.EnrichmentPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.devices.inputs.EnrichmentPropertiesArgs =
        com.pulumi.azurenative.devices.inputs.EnrichmentPropertiesArgs.builder()
            .endpointNames(endpointNames.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .key(key.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EnrichmentPropertiesArgs].
 */
@PulumiTagMarker
public class EnrichmentPropertiesArgsBuilder internal constructor() {
    private var endpointNames: Output<List<String>>? = null

    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The list of endpoints for which the enrichment is applied to the message.
     */
    @JvmName("dsncfvmvdxyanjhe")
    public suspend fun endpointNames(`value`: Output<List<String>>) {
        this.endpointNames = value
    }

    @JvmName("eyjspufrxorugcvk")
    public suspend fun endpointNames(vararg values: Output<String>) {
        this.endpointNames = Output.all(values.asList())
    }

    /**
     * @param values The list of endpoints for which the enrichment is applied to the message.
     */
    @JvmName("ldvatcemjkjmkdls")
    public suspend fun endpointNames(values: List<Output<String>>) {
        this.endpointNames = Output.all(values)
    }

    /**
     * @param value The key or name for the enrichment property.
     */
    @JvmName("ddemeddrgstlkukd")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The value for the enrichment property.
     */
    @JvmName("byliwapuggsqgtkj")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The list of endpoints for which the enrichment is applied to the message.
     */
    @JvmName("hcfboypvjyrtvqgk")
    public suspend fun endpointNames(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointNames = mapped
    }

    /**
     * @param values The list of endpoints for which the enrichment is applied to the message.
     */
    @JvmName("wlcrgkhqlhbmhpdw")
    public suspend fun endpointNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointNames = mapped
    }

    /**
     * @param value The key or name for the enrichment property.
     */
    @JvmName("uuwkvndusclpvnpt")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The value for the enrichment property.
     */
    @JvmName("egmynpyacqbubpjr")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): EnrichmentPropertiesArgs = EnrichmentPropertiesArgs(
        endpointNames = endpointNames ?: throw PulumiNullFieldException("endpointNames"),
        key = key ?: throw PulumiNullFieldException("key"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/devices/kotlin/inputs/EnrichmentPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devices.kotlin.inputs

import com.pulumi.azurenative.devices.inputs.EnrichmentPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of an enrichment that your IoT hub applies to messages delivered to endpoints.
 * @property endpointNames The list of endpoints for which the enrichment is applied to the message.
 * @property key The key or name for the enrichment property.
 * @property value The value for the enrichment property.
 */
public data class EnrichmentPropertiesArgs(
    public val endpointNames: Output<List<String>>,
    public val key: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.devices.inputs.EnrichmentPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.devices.inputs.EnrichmentPropertiesArgs =
        com.pulumi.azurenative.devices.inputs.EnrichmentPropertiesArgs.builder()
            .endpointNames(endpointNames.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .key(key.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EnrichmentPropertiesArgs].
 */
@PulumiTagMarker
public class EnrichmentPropertiesArgsBuilder internal constructor() {
    private var endpointNames: Output<List<String>>? = null

    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The list of endpoints for which the enrichment is applied to the message.
     */
    @JvmName("dodublgraumjwfav")
    public suspend fun endpointNames(`value`: Output<List<String>>) {
        this.endpointNames = value
    }

    @JvmName("jkbinoowvovwlfpa")
    public suspend fun endpointNames(vararg values: Output<String>) {
        this.endpointNames = Output.all(values.asList())
    }

    /**
     * @param values The list of endpoints for which the enrichment is applied to the message.
     */
    @JvmName("prbgaklcftqbnfly")
    public suspend fun endpointNames(values: List<Output<String>>) {
        this.endpointNames = Output.all(values)
    }

    /**
     * @param value The key or name for the enrichment property.
     */
    @JvmName("tjsfjsbqggqvsqpq")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The value for the enrichment property.
     */
    @JvmName("waitnnwwattpsrmy")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The list of endpoints for which the enrichment is applied to the message.
     */
    @JvmName("amntawreqoamdgnu")
    public suspend fun endpointNames(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointNames = mapped
    }

    /**
     * @param values The list of endpoints for which the enrichment is applied to the message.
     */
    @JvmName("kldprctgstrplbdd")
    public suspend fun endpointNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointNames = mapped
    }

    /**
     * @param value The key or name for the enrichment property.
     */
    @JvmName("uabolgvcsukrstjr")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The value for the enrichment property.
     */
    @JvmName("clbhjwcbcsjysede")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): EnrichmentPropertiesArgs = EnrichmentPropertiesArgs(
        endpointNames = endpointNames ?: throw PulumiNullFieldException("endpointNames"),
        key = key ?: throw PulumiNullFieldException("key"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
